summaryrefslogtreecommitdiff
path: root/page_history.php
diff options
context:
space:
mode:
authorJams H Thompson <jht001@users.sourceforge.net>2008-03-23 00:01:26 +0000
committerJams H Thompson <jht001@users.sourceforge.net>2008-03-23 00:01:26 +0000
commit5aa5609f4e2350c1f9f3d15d186fc9726b5a357d (patch)
tree501e0668cb6a437c1c32b6edb408bf8f59116713 /page_history.php
parentd6355aaf3e8a9ffaa7bf58f111b7b7355ad1ba1d (diff)
downloadwiki-5aa5609f4e2350c1f9f3d15d186fc9726b5a357d.tar.gz
wiki-5aa5609f4e2350c1f9f3d15d186fc9726b5a357d.tar.bz2
wiki-5aa5609f4e2350c1f9f3d15d186fc9726b5a357d.zip
eliminate dependency on get_bitpage_info.php
Diffstat (limited to 'page_history.php')
-rw-r--r--page_history.php12
1 files changed, 8 insertions, 4 deletions
diff --git a/page_history.php b/page_history.php
index 80e397a..c90bb5c 100644
--- a/page_history.php
+++ b/page_history.php
@@ -1,6 +1,6 @@
<?php
/**
- * $Header: /cvsroot/bitweaver/_bit_wiki/page_history.php,v 1.27 2008/03/22 21:37:47 jht001 Exp $
+ * $Header: /cvsroot/bitweaver/_bit_wiki/page_history.php,v 1.28 2008/03/23 00:01:26 jht001 Exp $
*
* Copyright (c) 2004 bitweaver.org
* Copyright (c) 2003 tikwiki.org
@@ -8,7 +8,7 @@
* All Rights Reserved. See copyright.txt for details and a complete list of authors.
* Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details
*
- * $Id: page_history.php,v 1.27 2008/03/22 21:37:47 jht001 Exp $
+ * $Id: page_history.php,v 1.28 2008/03/23 00:01:26 jht001 Exp $
* @package wiki
* @subpackage functions
*/
@@ -25,8 +25,10 @@ $gBitSystem->verifyFeature( 'wiki_history' );
// Get the page from the request var or default it to HomePage
include( WIKI_PKG_PATH.'lookup_page_inc.php' );
-//make info about page available for templates
-include( WIKI_PKG_PATH.'get_bitpage_info.php' );
+// make comment count for this page available for templates
+$gComment = new LibertyComment( NULL, $gContent->mContentId );
+$numComments = $gComment->getNumComments($gContent->mContentId);
+$gBitSmarty->assign('comments_count', $numComments);
//vd($gContent->mPageId);vd($gContent->mInfo);
if( !$gContent->isValid() || empty( $gContent->mInfo ) ) {
@@ -58,5 +60,7 @@ $gBitSmarty->assign_by_ref( 'listInfo', $history['listInfo'] );
// Display the template
$gBitSmarty->assign_by_ref( 'gContent', $gContent );
+$gBitSmarty->assign_by_ref( 'pageInfo', $gContent->mInfo );
+
$gBitSystem->display( 'bitpackage:wiki/page_history.tpl');
?>